#!/usr/bin/env python3
####################################################################
#   Copyright (C) 2020-2021 Luis Falcon <falcon@gnuhealth.org>
#   Copyright (C) 2020-2021 GNU Solidario <health@gnusolidario.org>
#   License: GPL v3+
#   Please read the COPYRIGHT and LICENSE files of the package
####################################################################

__version__ = "1.0.1"

__appname__ = "MyGNUHealth"

__description__ = "The GNU Health Personal Health Record"

__homepage__ = "https://www.gnuhealth.org"

__author__ = "Luis Falcon"

__email__ = "info@gnuhealth.org"

__download_url__ = 'https://ftp.gnu.org/gnu/health/mygnuhealth'

__license__ = "GPL v3+"
__copyright__ = "Copyright 2008-2021 GNU Solidario"

__thanks__ = ("Axel Braun\n"
              "Paul Brown\n"
              "Yuri Chornoivan\n"
              "Leonardo D'Acchille\n"
              "Marco Gebhardt\n"
              "Riccardo Iaconelli\n"
              "Cristian Maureira-Fredes\n"
              "Karl Ove Hufthammer\n"
              "Aleix Pol\n"
              "Carl Schwan\n"
              "Pino Toscano\n"
              "Niccolò Venerandi")
